@@ -18,9 +18,6 @@ if TYPE_CHECKING:
     from mkdocstrings_handlers.python.handler import PythonHandler
 
 
-pytest_plugins = ["griffe.tests"]
-
-
 @pytest.fixture(name="mkdocs_conf")
 def fixture_mkdocs_conf(request: pytest.FixtureRequest, tmp_path: Path) -> Iterator[config.Config]:
     """Yield a MkDocs configuration object.
@@ -37,6 +34,7 @@ def fixture_mkdocs_conf(request: pytest.FixtureRequest, tmp_path: Path) -> Itera
         request = request._parent_request
 
     conf_dict = {
+        "config_file_path": "mkdocs.yml",
         "site_name": "foo",
         "site_url": "https://example.org/",
         "site_dir": str(tmp_path),
